==> config-api-0.3.11-sources.jar: org/wildfly/swarm/config/messaging_activemq/server/InVMAcceptor.java <==
package org.wildfly.swarm.config.messaging_activemq.server;

import org.wildfly.swarm.config.runtime.Implicit;
import org.wildfly.swarm.config.runtime.ResourceType;
import org.wildfly.swarm.config.runtime.ModelNodeBinding;
import java.util.Map;
/**
 * Defines a way in which in-VM connections can be made to the ActiveMQ server.
 */
@ResourceType("in-vm-acceptor")
public class InVMAcceptor<T extends InVMAcceptor> {

	private String key;
	private Map params = new java.util.HashMap<String, Object>();
	private Integer serverId;
	private Boolean started;

	public InVMAcceptor(String key) {
		this.key = key;
	}

	public String getKey() {
		return this.key;
	}

	/**
	 * A key-value pair understood by the acceptor factory-class and used to configure it.
	 */
	@ModelNodeBinding(detypedName = "params")
	public Map params() {
		return this.params;
	}

	/**
	 * A key-value pair understood by the acceptor factory-class and used to configure it.
	 */
	@SuppressWarnings("unchecked")
	public InVMAcceptor params(Map value) {
		this.params = value;
		return (InVMAcceptor) this;
	}

	/**
	 * A key-value pair understood by the acceptor factory-class and used to configure it.
	 */
	public InVMAcceptor paramsEntry(String key, Object value) {
		this.params.put(key, value);
		return (InVMAcceptor) this;
	}

	/**
	 * The server id.
	 */
	@ModelNodeBinding(detypedName = "server-id")
	public Integer serverId() {
		return this.serverId;
	}

	/**
	 * The server id.
	 */
	@SuppressWarnings("unchecked")
	public InVMAcceptor serverId(Integer value) {
		this.serverId = value;
		return (InVMAcceptor) this;
	}

	/**
	 * Whether this acceptor is started.
	 */
	@ModelNodeBinding(detypedName = "started")
	public Boolean started() {
		return this.started;
	}

	/**
	 * Whether this acceptor is started.
	 */
	@SuppressWarnings("unchecked")
	public InVMAcceptor started(Boolean value) {
		this.started = value;
		return (InVMAcceptor) this;
	}
}

==> config-api-0.3.12-sources.jar: org/wildfly/swarm/config/messaging_activemq/server/InVMAcceptor.java <==
package org.wildfly.swarm.config.messaging_activemq.server;

import org.wildfly.swarm.config.runtime.Implicit;
import org.wildfly.swarm.config.runtime.ResourceType;
import org.wildfly.swarm.config.runtime.ModelNodeBinding;
import java.util.Map;
/**
 * Defines a way in which in-VM connections can be made to the ActiveMQ server.
 */
@ResourceType("in-vm-acceptor")
public class InVMAcceptor<T extends InVMAcceptor> {

	private String key;
	private Map params;
	private Integer serverId;
	private Boolean started;

	public InVMAcceptor(String key) {
		this.key = key;
	}

	public String getKey() {
		return this.key;
	}

	/**
	 * A key-value pair understood by the acceptor factory-class and used to configure it.
	 */
	@ModelNodeBinding(detypedName = "params")
	public Map params() {
		return this.params;
	}

	/**
	 * A key-value pair understood by the acceptor factory-class and used to configure it.
	 */
	@SuppressWarnings("unchecked")
	public T params(Map value) {
		this.params = value;
		return (T) this;
	}

	/**
	 * A key-value pair understood by the acceptor factory-class and used to configure it.
	 */
	public T param(String key, Object value) {
		if (this.params == null) {
			this.params = new java.util.HashMap<>();
		}
		this.params.put(key, value);
		return (T) this;
	}

	/**
	 * The server id.
	 */
	@ModelNodeBinding(detypedName = "server-id")
	public Integer serverId() {
		return this.serverId;
	}

	/**
	 * The server id.
	 */
	@SuppressWarnings("unchecked")
	public T serverId(Integer value) {
		this.serverId = value;
		return (T) this;
	}

	/**
	 * Whether this acceptor is started.
	 */
	@ModelNodeBinding(detypedName = "started")
	public Boolean started() {
		return this.started;
	}

	/**
	 * Whether this acceptor is started.
	 */
	@SuppressWarnings("unchecked")
	public T started(Boolean value) {
		this.started = value;
		return (T) this;
	}
}
